@@ -1,3 +1,4 @@
+debug = True
 from splitapiclient.resources.traffic_type import TrafficType
 from splitapiclient.resources.environment import Environment
 from splitapiclient.resources.split import Split
@@ -11,3 +12,4 @@ from splitapiclient.resources.change_request import ChangeRequest
 from splitapiclient.resources.user import User
 from splitapiclient.resources.group import Group
 from splitapiclient.resources.apikey import APIKey
+from splitapiclient.resources.restriction import Restriction
